@@ -5,6 +5,7 @@ import keyring
 import os
 import socket
 from pathlib import Path
+from tenacity import retry, wait_fixed, stop_after_attempt
 from time import time
 
 import click
@@ -63,11 +64,22 @@ class ConfigReaderAndWriter:
         except keyring.errors.PasswordDeleteError:
             pass
 
-    def decode(self):
+    @retry(reraise=True, stop=stop_after_attempt(3), wait=wait_fixed(2))
+    def get_from_keyring(self):
         user = keyring.get_password("geospock", self.profile + "-username")
         password = keyring.get_password("geospock", self.profile + "-password")
         return user, password
 
+    def decode(self):
+        try:
+            user, password = self.get_from_keyring()
+        except keyring.errors.KeyringError as ke:
+            click.secho("Cannot retrieve login details from Keyring", fg="red")
+            raise CLIError(str(ke))
+        if user is None or password is None:
+            raise CLIError(ConfigReaderAndWriter.MESSAGES["insufficientLoginDetails"])
+        return user, password
+
     def write_to_config(self, client_id: str, audience: str, auth0url: str, request_address: str) -> None:
         Path(self.GEOSPOCK_DIR).mkdir(parents=True, exist_ok=True)
 
