@@ -57,6 +57,8 @@ def get_header(config_reader: ConfigReaderAndWriter, user: str, password: str, r
         try:
             username, password = config_reader.decode()
             return get_basic_auth_header(username, password, request_address)
+        except CLIError as cli_error:
+            raise cli_error
         except Exception:
             raise CLIError(ConfigReaderAndWriter.MESSAGES["insufficientLoginDetails"])
 
